@@ -1,4 +1,4 @@
 from .base_dataset import BaseDataset
 from .collate import *
-from .mydata import MyDataset
+from .dataset_gpt import GPTDataset
 from .transforms import *  # noqa: F401,F403
